@@ -1,7 +1,7 @@
 #! /bin/sh
 
 top=`pwd`
-gcc_version=9.3.0
+gcc_version=10.3.0
 contact="Andris Pavenis <andris.pavenis@iki.fi>";
 
 # Configuration params
@@ -67,12 +67,19 @@ devphase=$(cat gnu/$orig_dir_name/gcc/DEV-PHASE)
 version=$base_ver
 version_desc=$version
 
+
 #  X.Y.Z ==> X.YZ
 short_ver=$(echo $version | sed -e 's:\.::2g')
 
 #  X.Y.Z ==> XYZ
 short_ver_2=$(echo $version | sed -e 's:\.::g')
 
+if test -z "$devphase"; then
+    case "$base_ver" in
+    10.0.* | 10.[1-9].[1-9]) devphase=prerelease ;;
+    esac
+fi
+
 if ! test -z "$devphase"; then
     version=${base_ver}-${datestamp}
     version_desc="$base_ver $datestamp ($devphase)"
